aboutsummaryrefslogtreecommitdiffstats
path: root/cmake/modules/FindSparkle.cmake
diff options
context:
space:
mode:
Diffstat (limited to 'cmake/modules/FindSparkle.cmake')
-rw-r--r--cmake/modules/FindSparkle.cmake15
1 files changed, 12 insertions, 3 deletions
diff --git a/cmake/modules/FindSparkle.cmake b/cmake/modules/FindSparkle.cmake
index 7da80be0ea..5c14080d08 100644
--- a/cmake/modules/FindSparkle.cmake
+++ b/cmake/modules/FindSparkle.cmake
@@ -2,9 +2,9 @@
# Find the Sparkle framework
#
# This defines the following:
# SPARKLE_FOUND - True if we found Sparkle
# SPARKLE_INCLUDE_DIR - Path to Sparkle.h
# SPARKLE_LIBRARY - Path to Sparkle.framework
include(FindPackageHandleStandardArgs)
@@ -19,4 +19,13 @@ find_library(SPARKLE_LIBRARY NAMES Sparkle
)
find_package_handle_standard_args(Sparkle DEFAULT_MSG SPARKLE_INCLUDE_DIR SPARKLE_LIBRARY)
+
+if(SPARKLE_FOUND)
+ set(SPARKLE_LIBRARIES ${SPARKLE_LIBRARY} )
+ set(SPARKLE_INCLUDE_DIRS ${SPARKLE_INCLUDE_DIR} )
+else(SPARKLE_FOUND)
+ set(SPARKLE_LIBRARIES )
+ set(SPARKLE_INCLUDE_DIRS )
+endif(SPARKLE_FOUND)
+
mark_as_advanced(SPARKLE_INCLUDE_DIR SPARKLE_LIBRARY)
@@ -2,9 +2,9 @@
#
# This defines the following:
-# SPARKLE_FOUND - True if we found Sparkle
-# SPARKLE_INCLUDE_DIR - Path to Sparkle.h
-# SPARKLE_LIBRARY - Path to Sparkle.framework
+# SPARKLE_FOUND - True if we found Sparkle
+# SPARKLE_INCLUDE_DIRS - Path to Sparkle.h, empty if not found
+# SPARKLE_LIBRARIES - Path to Sparkle.framework, empty if not found
include(FindPackageHandleStandardArgs)